<template>
  <section class="bg--gray">
    <v-container>
      <SharedBreadcrumbs :items="items" />
      <v-row>
        <v-col cols="12" lg="6">
          <v-card class="white px-6 py-6 mt-10 border-gray rounded-lg">
            <div class="text-center">
              <h2>
                {{ $t("contact") }}
              </h2>
              <p class="color--gray">
                {{ $t("contact_description") }}
              </p>
            </div>

            <Form @submit="submited">
              <SharedInputText
                v-if="render"
                validation="required"
                :form="form"
                name="name"
                label="name"
                variant="outlined"
                :placeholder="$t('enter_name')"
              />
              <SharedInputText
                v-if="render"
                validation="required|email"
                :form="form"
                name="email"
                label="email"
                variant="outlined"
                :placeholder="$t('enter_email')"
              />
              <!-- <SharedInputText
              validation="required|email"
              :form="form"
              name="phone"
              label="phone"
            /> -->

              <SharedInputTextarea
                v-if="render"
                validation="required"
                :form="form"
                name="message"
                label="message"
                variant="outlined"
                :placeholder="$t('message')"
              />
              <SharedButton
                :loading="loading"
                type="sumbit"
                color="primary"
                class="mt-4"
                block
              >
                {{ $t("send") }}
              </SharedButton>
            </Form>
          </v-card>
        </v-col>
        <v-col cols="12" lg="6" class="pt-13">
          <div class="bg-white py-4 px-4 mb-5 rounded-lg border-gray">
            <div class="d-flex">
              <div>
                <LazySharedImage name="address-icon.svg" />
              </div>
              <div class="mx-2">
                <h3>
                  {{ $t("visit_us") }}
                </h3>
                <p class="color--gray">القاهرة, مصر, 123 شارع الهرم</p>
              </div>
            </div>
          </div>
          <div class="bg-white py-4 px-4 mb-5 rounded-lg border-gray">
            <div class="d-flex">
              <div>
                <LazySharedImage name="email-icon.svg" />
              </div>
              <div class="mx-2">
                <h3>
                  {{ $t("send_to_us") }}
                </h3>

                <p class="color--gray">القاهرة, مصر, 123 شارع الهرم</p>
              </div>
            </div>
          </div>
          <div class="bg-white py-4 px-4 mb-5 rounded-lg border-gray">
            <div class="d-flex">
              <div>
                <LazySharedImage name="phone-icon.svg" />
              </div>
              <div class="mx-2">
                <h3>
                  {{ $t("contact_to_us") }}
                </h3>

                <p class="color--gray">القاهرة, مصر, 123 شارع الهرم</p>
              </div>
            </div>
          </div>
        </v-col>
      </v-row>
    </v-container>
  </section>
</template>

<script setup>
const { t } = useI18n();

const items = ref([
  {
    title: t("home"),
    disabled: false,
    href: "/",
  },
  {
    title: t("contact"),
    disabled: true,
    href: "",
  },
]);
import useApi from "@/composables/useApi";
const render = ref(true);
let form = ref({
  name: "",
  email: "",
  message: "",
});

const { post, loading } = useApi();

const submited = async () => {
  await post("contact", form.value);
  form.value = {
    name: "",
    email: "",
    message: "",
  };
  render.value = false;
  nextTick(() => {
    render.value = true;
  });
};
</script>
